==> TencentNavKitDocument_6.13.0.zip: TencentNavKitDocument/search/all_e.js <==
var searchData=
[
  ['name_0',['name',['../interface_t_n_k_highway_facility_item.html#a5d4a491d6289f28a2dd4af0b38f79fea',1,'TNKHighwayFacilityItem']]],
  ['navdatasource_1',['navDataSource',['../interface_t_n_k_drive_nav_manager.html#ad6a4c2ba08338540930799f0d60928ed',1,'TNKDriveNavManager::navDataSource()'],['../interface_t_n_k_ride_nav_manager.html#a8764f2c5ebd9c9b26d9abe03bd1a49c8',1,'TNKRideNavManager::navDataSource()'],['../interface_t_n_k_walk_nav_manager.html#ab0c9d3f78714d9abf7cf1b79fe49b1b3',1,'TNKWalkNavManager::navDataSource()']]],
  ['navigationpanelenabled_2',['navigationPanelEnabled',['../interface_t_n_k_drive_nav_view.html#a1bae7781f28e6024d3074b6e21567d7a',1,'TNKDriveNavView']]],
  ['navisessionid_3',['naviSessionID',['../interface_t_n_k_drive_route_search_result.html#af4e08f73a8f83d9fdc867f323121068c',1,'TNKDriveRouteSearchResult']]],
  ['navrestrictioninfo_4',['navRestrictionInfo',['../interface_t_n_k_drive_navigation_data.html#a1c568ab2f271d1cb8dd94f4334dd2419',1,'TNKDriveNavigationData']]],
  ['navscene_5',['navScene',['../interface_t_n_k_drive_route_search_option.html#ae43f25c12d35161e8fad37b760acbbb2',1,'TNKDriveRouteSearchOption']]],
  ['navuimode_6',['navUIMode',['../interface_t_n_k_base_nav_view.html#aedc7298a8e0135d290a39f8fb7ff1247',1,'TNKBaseNavView']]],
  ['navview_3adidchangedaynightstatus_3a_7',['navView:didChangeDayNightStatus:',['../protocol_t_n_k_base_nav_view_delegate-p.html#ad62f7aa157513b8b88248e02d4c1d9f4',1,'TNKBaseNavViewDelegate-p::navView:didChangeDayNightStatus:()'],['../protocol_t_n_k_drive_nav_view_delegate-p.html#af5dcc0e8fb91110fda31a3ebec0620bc',1,'TNKDriveNavViewDelegate-p::navView:didChangeDayNightStatus:(TNKBaseNavView *navView,[didChangeDayNightStatus] TNKNavDayNightStatus status)']]],
  ['navview_3adidchangeuimode_3a_8',['navView:didChangeUIMode:',['../protocol_t_n_k_drive_nav_view_delegate-p.html#af12eec6fb836af7679e77ef5e06a044d',1,'TNKDriveNavViewDelegate-p']]],
  ['navview_3adidchangeuimode_3afollowed_3a_9',['navView:didChangeUIMode:followed:',['../protocol_t_n_k_base_nav_view_delegate-p.html#ab66b48b16376dde86c4117590febbfbb',1,'TNKBaseNavViewDelegate-p']]],
  ['navviewclosebuttonclicked_3a_10',['navViewCloseButtonClicked:',['../protocol_t_n_k_base_nav_view_delegate-p.html#abe9f3a1b145c9545c939ebdbb929a378',1,'TNKBaseNavViewDelegate-p::navViewCloseButtonClicked:()'],['../protocol_t_n_k_drive_nav_view_delegate-p.html#a853aeebb717a84f5ae69ef6e0efd09f4',1,'TNKDriveNavViewDelegate-p::navViewCloseButtonClicked:(TNKBaseNavView *navView)']]],
  ['navviewdidhideenlargedmap_3a_11',['navViewDidHideEnlargedMap:',['../protocol_t_n_k_drive_nav_view_delegate-p.html#aa1c9e97c5ae29fa280421e8218eba8fa',1,'TNKDriveNavViewDelegate-p']]],
  ['navviewdidshowenlargedmap_3a_12',['navViewDidShowEnlargedMap:',['../protocol_t_n_k_drive_nav_view_delegate-p.html#ae90a25246c0c5d5620fd047669c6d5b4',1,'TNKDriveNavViewDelegate-p']]],
  ['needexperienceroute_13',['needExperienceRoute',['../interface_t_n_k_truck_search_option.html#aecfb7f4444297b5732a452dfd924140a',1,'TNKTruckSearchOption']]],
  ['nextdistanceleft_14',['nextDistanceLeft',['../interface_t_n_k_drive_navigation_data.html#ad2b63b9fcc513a83bffd9d4e67c1cc95',1,'TNKDriveNavigationData::nextDistanceLeft()'],['../interface_t_n_k_ride_navigation_data.html#aec32917691b72f0ac724beb6cc9282ca',1,'TNKRideNavigationData::nextDistanceLeft()'],['../interface_t_n_k_walk_navigation_data.html#a70f57b42e06aabd8225106b197a835d3',1,'TNKWalkNavigationData::nextDistanceLeft()']]],
  ['nextendtimestamp_15',['nextEndTimestamp',['../interface_t_n_k_traffic_light_countdown_msg.html#a16f272591805fc9bad5375a96daddf83',1,'TNKTrafficLightCountdownMsg']]],
  ['nextintersectionimage_16',['nextIntersectionImage',['../interface_t_n_k_drive_navigation_data.html#a81cf79eb3eafdac22acef837fa202ed6',1,'TNKDriveNavigationData']]],
  ['nextnextroadname_17',['nextNextRoadName',['../interface_t_n_k_drive_navigation_data.html#a2f296d9bf2aa2432be2f850732fc2a68',1,'TNKDriveNavigationData']]],
  ['nextroadname_18',['nextRoadName',['../interface_t_n_k_drive_navigation_data.html#a1e8237f78202e0f08afe281aa01f72b8',1,'TNKDriveNavigationData::nextRoadName()'],['../interface_t_n_k_ride_navigation_data.html#a0986a1b97cc1779df6709b4822d405bd',1,'TNKRideNavigationData::nextRoadName()'],['../interface_t_n_k_walk_navigation_data.html#aff945dfb3f397589f18fe2e44912a036',1,'TNKWalkNavigationData::nextRoadName()']]],
  ['nexttrafficlighttype_19',['nextTrafficLightType',['../interface_t_n_k_traffic_light_countdown_msg.html#a49aa949bd105f8c95eeed0c3d57c8fa0',1,'TNKTrafficLightCountdownMsg']]],
  ['nightfillcolorpalette_20',['nightFillColorPalette',['../interface_t_n_k_route_line_config.html#a67d31304ffa41d8a502023dbc22c5cbc',1,'TNKRouteLineConfig']]],
  ['nightstrokecolorpalette_21',['nightStrokeColorPalette',['../interface_t_n_k_route_line_config.html#a701a0e837388f004cc740bd9c6c69dff',1,'TNKRouteLineConfig']]],
  ['nightuserlocationconfig_22',['nightUserLocationConfig',['../interface_t_n_k_user_location_presentation.html#a95b9e4d317ba34632b26bd66390544f3',1,'TNKUserLocationPresentation']]],
  ['nonoverviewnaviuimode_23',['nonOverviewNaviUIMode',['../interface_t_n_k_base_nav_view.html#ac2e496a3836fa78f76ae0d784e790f26',1,'TNKBaseNavView']]],
  ['northimage_24',['northImage',['../interface_t_n_k_user_location_config.html#ac55850e7d3c76d4507677034a6674802',1,'TNKUserLocationConfig']]],
  ['ns_5fenum_25',['NS_ENUM',['../_t_n_k_audio_player_protocol_8h.html#ac0eb032e36f00f5163f431fd4cebba9d',1,'NS_ENUM(NSUInteger, TNKAudioPlayRateType):&#160;TNKAudioPlayerProtocol.h'],['../_t_n_k_drive_route_explain_8h.html#ad366b1e6fd4c3e4ee50cecbe0449ecad',1,'NS_ENUM(NSUInteger, TNKDriveRouteExplainType):&#160;TNKDriveRouteExplain.h'],['../_t_n_k_location_simulator_8h.html#aebf9f121b35b0978e4521b72b8ae08bf',1,'NS_ENUM(NSInteger, TNKSimulateLocationsType):&#160;TNKLocationSimulator.h'],['../_t_n_k_navi_traffic_bar_widget_8h.html#ae69c7e6c41ffbf3ffb7a7c46850961a5',1,'NS_ENUM(NSUInteger, TNKNaviTrafficBarWidgetOrientation):&#160;TNKNaviTrafficBarWidget.h']]],
  ['ns_5foptions_26',['NS_OPTIONS',['../_t_n_k_drive_common_obj_8h.html#a6978fdb7e73dc21a23312562dadba2bd',1,'TNKDriveCommonObj.h']]],
  ['ns_5funavailable_27',['NS_UNAVAILABLE',['../interface_t_n_k_drive_nav_route.html#aebb6ca73ce5dc87c44f34f412954feb5',1,'TNKDriveNavRoute::NS_UNAVAILABLE()'],['../interface_t_n_k_drive_route_plan_service.html#a2fc875fa7b4e25cc430f0e89fee0ff5a',1,'TNKDriveRoutePlanService::NS_UNAVAILABLE()'],['../interface_t_n_k_ride_nav_route.html#af166ee2e36ff1d7c66f2eea32de29456',1,'TNKRideNavRoute::NS_UNAVAILABLE()'],['../interface_t_n_k_walk_nav_route.html#a464fed45228b3f4d2f175499285f726b',1,'TNKWalkNavRoute::NS_UNAVAILABLE()']]],
  ['numoflane_28',['numOfLane',['../interface_t_n_k_lane_info.html#a1d8f55802cc7ef8dfbcf9062a0a964b6',1,'TNKLaneInfo']]]
];

==> TencentNavKitDocument_7.1.1.zip: TencentNavKitDocument/search/all_e.js <==
var searchData=
[
  ['name_0',['name',['../interface_t_n_k_highway_facility_item.html#a5d4a491d6289f28a2dd4af0b38f79fea',1,'TNKHighwayFacilityItem']]],
  ['navdatasource_1',['navDataSource',['../interface_t_n_k_drive_nav_manager.html#ad6a4c2ba08338540930799f0d60928ed',1,'TNKDriveNavManager::navDataSource()'],['../interface_t_n_k_ride_nav_manager.html#a8764f2c5ebd9c9b26d9abe03bd1a49c8',1,'TNKRideNavManager::navDataSource()'],['../interface_t_n_k_walk_nav_manager.html#ab0c9d3f78714d9abf7cf1b79fe49b1b3',1,'TNKWalkNavManager::navDataSource()']]],
  ['navigationpanelenabled_2',['navigationPanelEnabled',['../interface_t_n_k_drive_nav_view.html#a1bae7781f28e6024d3074b6e21567d7a',1,'TNKDriveNavView::navigationPanelEnabled()'],['../interface_t_n_k_u_i_component_config.html#a2b09ce39639bcad3df9facb6c22dfd31',1,'TNKUIComponentConfig::navigationPanelEnabled()']]],
  ['navisessionid_3',['naviSessionID',['../interface_t_n_k_drive_route_search_result.html#af4e08f73a8f83d9fdc867f323121068c',1,'TNKDriveRouteSearchResult']]],
  ['navrestrictioninfo_4',['navRestrictionInfo',['../interface_t_n_k_drive_navigation_data.html#a1c568ab2f271d1cb8dd94f4334dd2419',1,'TNKDriveNavigationData']]],
  ['navscene_5',['navScene',['../interface_t_n_k_drive_route_search_option.html#ae43f25c12d35161e8fad37b760acbbb2',1,'TNKDriveRouteSearchOption']]],
  ['navuimode_6',['navUIMode',['../interface_t_n_k_base_nav_view.html#aedc7298a8e0135d290a39f8fb7ff1247',1,'TNKBaseNavView']]],
  ['navview_3adidchangedaynightstatus_3a_7',['navView:didChangeDayNightStatus:',['../protocol_t_n_k_base_nav_view_delegate-p.html#ad62f7aa157513b8b88248e02d4c1d9f4',1,'TNKBaseNavViewDelegate-p::navView:didChangeDayNightStatus:()'],['../protocol_t_n_k_drive_nav_view_delegate-p.html#af5dcc0e8fb91110fda31a3ebec0620bc',1,'TNKDriveNavViewDelegate-p::navView:didChangeDayNightStatus:(TNKBaseNavView *navView,[didChangeDayNightStatus] TNKNavDayNightStatus status)']]],
  ['navview_3adidchangeuimode_3a_8',['navView:didChangeUIMode:',['../protocol_t_n_k_drive_nav_view_delegate-p.html#af12eec6fb836af7679e77ef5e06a044d',1,'TNKDriveNavViewDelegate-p']]],
  ['navview_3adidchangeuimode_3afollowed_3a_9',['navView:didChangeUIMode:followed:',['../protocol_t_n_k_base_nav_view_delegate-p.html#ab66b48b16376dde86c4117590febbfbb',1,'TNKBaseNavViewDelegate-p']]],
  ['navviewclosebuttonclicked_3a_10',['navViewCloseButtonClicked:',['../protocol_t_n_k_base_nav_view_delegate-p.html#abe9f3a1b145c9545c939ebdbb929a378',1,'TNKBaseNavViewDelegate-p::navViewCloseButtonClicked:()'],['../protocol_t_n_k_drive_nav_view_delegate-p.html#a853aeebb717a84f5ae69ef6e0efd09f4',1,'TNKDriveNavViewDelegate-p::navViewCloseButtonClicked:(TNKBaseNavView *navView)']]],
  ['navviewdidhideenlargedmap_3a_11',['navViewDidHideEnlargedMap:',['../protocol_t_n_k_drive_nav_view_delegate-p.html#aa1c9e97c5ae29fa280421e8218eba8fa',1,'TNKDriveNavViewDelegate-p']]],
  ['navviewdidshowenlargedmap_3a_12',['navViewDidShowEnlargedMap:',['../protocol_t_n_k_drive_nav_view_delegate-p.html#ae90a25246c0c5d5620fd047669c6d5b4',1,'TNKDriveNavViewDelegate-p']]],
  ['needexperienceroute_13',['needExperienceRoute',['../interface_t_n_k_truck_search_option.html#aecfb7f4444297b5732a452dfd924140a',1,'TNKTruckSearchOption']]],
  ['nextdistanceleft_14',['nextDistanceLeft',['../interface_t_n_k_drive_navigation_data.html#ad2b63b9fcc513a83bffd9d4e67c1cc95',1,'TNKDriveNavigationData::nextDistanceLeft()'],['../interface_t_n_k_ride_navigation_data.html#aec32917691b72f0ac724beb6cc9282ca',1,'TNKRideNavigationData::nextDistanceLeft()'],['../interface_t_n_k_walk_navigation_data.html#a70f57b42e06aabd8225106b197a835d3',1,'TNKWalkNavigationData::nextDistanceLeft()']]],
  ['nextendtimestamp_15',['nextEndTimestamp',['../interface_t_n_k_traffic_light_countdown_msg.html#a16f272591805fc9bad5375a96daddf83',1,'TNKTrafficLightCountdownMsg']]],
  ['nextintersectionimage_16',['nextIntersectionImage',['../interface_t_n_k_drive_navigation_data.html#a81cf79eb3eafdac22acef837fa202ed6',1,'TNKDriveNavigationData']]],
  ['nextnextroadname_17',['nextNextRoadName',['../interface_t_n_k_drive_navigation_data.html#a2f296d9bf2aa2432be2f850732fc2a68',1,'TNKDriveNavigationData']]],
  ['nextroadname_18',['nextRoadName',['../interface_t_n_k_drive_navigation_data.html#a1e8237f78202e0f08afe281aa01f72b8',1,'TNKDriveNavigationData::nextRoadName()'],['../interface_t_n_k_ride_navigation_data.html#a0986a1b97cc1779df6709b4822d405bd',1,'TNKRideNavigationData::nextRoadName()'],['../interface_t_n_k_walk_navigation_data.html#aff945dfb3f397589f18fe2e44912a036',1,'TNKWalkNavigationData::nextRoadName()']]],
  ['nexttrafficlighttype_19',['nextTrafficLightType',['../interface_t_n_k_traffic_light_countdown_msg.html#a49aa949bd105f8c95eeed0c3d57c8fa0',1,'TNKTrafficLightCountdownMsg']]],
  ['nightfillcolorpalette_20',['nightFillColorPalette',['../interface_t_n_k_route_line_config.html#a67d31304ffa41d8a502023dbc22c5cbc',1,'TNKRouteLineConfig']]],
  ['nightstrokecolorpalette_21',['nightStrokeColorPalette',['../interface_t_n_k_route_line_config.html#a701a0e837388f004cc740bd9c6c69dff',1,'TNKRouteLineConfig']]],
  ['nightuserlocationconfig_22',['nightUserLocationConfig',['../interface_t_n_k_user_location_presentation.html#a95b9e4d317ba34632b26bd66390544f3',1,'TNKUserLocationPresentation']]],
  ['nonoverviewnaviuimode_23',['nonOverviewNaviUIMode',['../interface_t_n_k_base_nav_view.html#ac2e496a3836fa78f76ae0d784e790f26',1,'TNKBaseNavView']]],
  ['northimage_24',['northImage',['../interface_t_n_k_user_location_config.html#ac55850e7d3c76d4507677034a6674802',1,'TNKUserLocationConfig']]],
  ['ns_5fenum_25',['NS_ENUM',['../_t_n_k_audio_player_protocol_8h.html#ac0eb032e36f00f5163f431fd4cebba9d',1,'NS_ENUM(NSUInteger, TNKAudioPlayRateType):&#160;TNKAudioPlayerProtocol.h'],['../_t_n_k_drive_route_explain_8h.html#ad366b1e6fd4c3e4ee50cecbe0449ecad',1,'NS_ENUM(NSUInteger, TNKDriveRouteExplainType):&#160;TNKDriveRouteExplain.h'],['../_t_n_k_location_simulator_8h.html#aebf9f121b35b0978e4521b72b8ae08bf',1,'NS_ENUM(NSInteger, TNKSimulateLocationsType):&#160;TNKLocationSimulator.h'],['../_t_n_k_navi_traffic_bar_widget_8h.html#ae69c7e6c41ffbf3ffb7a7c46850961a5',1,'NS_ENUM(NSUInteger, TNKNaviTrafficBarWidgetOrientation):&#160;TNKNaviTrafficBarWidget.h']]],
  ['ns_5foptions_26',['NS_OPTIONS',['../_t_n_k_drive_common_obj_8h.html#a6978fdb7e73dc21a23312562dadba2bd',1,'TNKDriveCommonObj.h']]],
  ['ns_5funavailable_27',['NS_UNAVAILABLE',['../interface_t_n_k_drive_nav_route.html#aebb6ca73ce5dc87c44f34f412954feb5',1,'TNKDriveNavRoute::NS_UNAVAILABLE()'],['../interface_t_n_k_drive_route_plan_service.html#a2fc875fa7b4e25cc430f0e89fee0ff5a',1,'TNKDriveRoutePlanService::NS_UNAVAILABLE()'],['../interface_t_n_k_ride_nav_route.html#af166ee2e36ff1d7c66f2eea32de29456',1,'TNKRideNavRoute::NS_UNAVAILABLE()'],['../interface_t_n_k_walk_nav_route.html#a464fed45228b3f4d2f175499285f726b',1,'TNKWalkNavRoute::NS_UNAVAILABLE()']]],
  ['numoflane_28',['numOfLane',['../interface_t_n_k_lane_info.html#a1d8f55802cc7ef8dfbcf9062a0a964b6',1,'TNKLaneInfo']]]
];
